#!/bin/bash
{% for p in paths %}
f{{p.ind}}=$(find {{p.dest_path}} -mindepth 1 -type d -printf "%f ")
{% endfor %}

_gcliComplete()
{
    local cur=${COMP_WORDS[COMP_CWORD]}
    COMPREPLY=( $(compgen -W "{% for p in paths %} $f{{p.ind}} {% endfor %}" -- $cur) )
}

complete -F _gcliComplete gcli
