{
    "repositories": [{
        "type": "package",
        "package": {
            "name": "{{plugin_name}}/{{plugin_name}}",
            "version": "{{version}}",
            "dist": {
                "url": "{{presigned_url}}",
                "type": "tar"
            },
            "autoload": {
                "classmap": [
                    "/"
                ]
            }
        }
    }],
    "require": {
        "{{plugin_name}}/{{plugin_name}}": "{{version}}"
    }
}